#!/bin/bash 

# NOTA: le coordinate iniziano dal vertice superiore sinistro dello schermo, equivalente a 0,0

# I valori vengono passati dal file "autostart-chromium" e nello specifico sono equivalenti a:
#
# variabile $1=200 - coordinata sullo schermo oltre il quale il puntatore del mouse "più a sinistra" non deve andare.
# variabile $2=100 - coordinata sullo schermo oltre il quale il puntatore del mouse "più in alto" non deve andare.
# variabile $3=800 - coordinata sullo schermo oltre il quale il puntatore del mouse "più a destra" non deve andare.
# variabile $4=600 - coordinata sullo schermo oltre il quale il puntatore del mouse "più in basso" non deve andare.
#
# Naturalmente ognuno potrà passare i valori più idonei in funzione del proprio target e dello schermo in uso.

BORDO_LIMITE_SINISTRO=$1
BORDO_LIMITE_SUPERIORE=$2
BORDO_LIMITE_DESTRO=$3
BORDO_LIMITE_INFERIORE=$4

# Variabile di verifica.
VERIFICA=0

# I due "if" che seguono verificano che, ad esempio, il limite sinistro non si trovi più a destra di quello destro
# (o viceversa, il bordo destro non si trovi più a sinistra di quello sinistro) e che il limite inferiore non sia
# maggiore di quello superiore (o viceversa), nel qual caso lo script non viene eseguito poiché trattasi di valori
# evidentemente sbagliati! Nel costrutto condizionale "-gt" sta per "greater than" (maggiore di).
if [ $BORDO_LIMITE_SINISTRO -gt $BORDO_LIMITE_DESTRO ]
then
    VERIFICA=1
fi

if [ $BORDO_LIMITE_SUPERIORE -gt $BORDO_LIMITE_INFERIORE ]
then
    VERIFICA=1
fi
# FINE #

# Se la verifica preliminare precedente viene superata si passa nel parte principale dello script. Si ricorda che
# "-lt" sta per "less than" (minore di).
if [ $VERIFICA -lt "1" ]
then
    # Loop infinito
    while [ true ]
    do
        VERIFICA=0
        # La posizione del puntatore del mouse è ottenuta richiamando l'opzione "getmouselocation" del programma
        # "xdotool" il quale, però, fornisce un output del tipo:
        #
        # x:604 y:817 screen:0 window:56623107
        #
        # Ma i campi di nostro interesse sono il primo e il secondo, rispettivamente per la posizione X e Y. Allora
        # passando in pipe (simbolo "|") l'output a "awk" (linguaggio di programmazione interpretato orientato alla
        # gestione dei dati di tipo testuale) filtreremo solo il primo e secondo campo utilizzando '{print $1}' per
        # la posizione X e '{print $2}' per la posizione Y. Il tutto è racchiuso all'interno di una espansione (o
        # sostituzione) di comando: apice/apostrofo inverso, meglio noto come backtick ottenibile con la
        # combinazione di tasti "AltGr-?". A questo punto la variabile "POS_X" sarà uguale a "x:604".
        POS_X=`xdotool getmouselocation | awk '{print $1}'`
        # A noi, però, interessa solo il valore numerico, allora ecco che facciamo uso di un'espansione di parametro
        # che taglia i primi due caratteri e solo a questo punto la variabile "POS_X" conterrà il valore numerico
        # "604" che da la posizione X del cursore.
        #
        # NOTA: non si confonda l'espansione di parametro con l'espansione di comando, quest'ultima ottenibile oltre
        # che con l'uso del backtick anche con la sintassi "$(comando)", ovvero con parentesi tonde! Nel caso della
        # espansione di parametro vengono utilizzate le parentesi graffe! L'espansione di parametro utilizzata nella
        # riga successiva è il modo più semplice e intuitivo di utilizzo, per i tutti i dettagli si rimanda al
        # manuale "man bash" nella sezione "EXPANSION" e sotto-sezione "Parameter Expansion".
        POS_X=${POS_X:2}
        # Analoghe considerazioni per la posizione attuale Y del mouse.
        POS_Y=`xdotool getmouselocation | awk '{print $2}'`
        POS_Y=${POS_Y:2}
        
        # I quattro "if" che seguono effettuano la verifica tra la posizione attuale del mouse e i limiti impostati
        # e passati allo script. Ad esempio se "POS_X", che memorizza l'attuale posizione del mouse, si trova più
        # a destra del limite destro la variabile 'VERIFICA' viene posta a 1 e la variabile "POS_X" viene impostata
        # al valore "BORDO_LIMITE_DESTRO" passato dal file "autostart-chromium". Analoghe considerazioni per i
        # successivi "if".
        if [ $POS_X -gt $BORDO_LIMITE_DESTRO ]
        then
            VERIFICA=1
            POS_X=$BORDO_LIMITE_DESTRO
        fi
        #
        if [ $POS_Y -gt $BORDO_LIMITE_INFERIORE ]
        then
            VERIFICA=1
            POS_Y=$BORDO_LIMITE_INFERIORE
        fi
        #
        if [ $POS_X -lt $BORDO_LIMITE_SINISTRO ]
        then
            VERIFICA=1
            POS_X=$BORDO_LIMITE_SINISTRO
        fi
        #
        if [ $POS_Y -lt $BORDO_LIMITE_SUPERIORE ]
        then
            VERIFICA=1
            POS_Y=$BORDO_LIMITE_SUPERIORE
        fi
        # FINE #
        
        # Terminata la verifica degli "if", e se almeno in uno di essi la variabile "VERIFICA" è stata posta pari
        # a 1, si entra nell'if che segue: "-ge" sta per "maggiore di o uguale a".
        if [ $VERIFICA -ge "1" ]
        then
            # L'opzione "mousemove" di "xdotool" sposta il mouse nei due argomenti che gli vengono passati. Nello
            # specifico se il mouse supera il perimetro oltre il quale non deve andare ecco che viene riportato
            # al limite di quel perimetro. Se si prova ad andare anche 1 pixel oltre il puntatore viene riportato
            # automaticamente al suo bordo limite (inferiore, superiore, destro e/o sinistro che sia).
            xdotool mousemove $POS_X $POS_Y
        fi
    done    
fi
